/* This file is part of the wvWare 2 project
   Copyright (C) 2002 Werner Trobin <trobin@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef HANDLERTEST_H
#define HANDLERTEST_H

#include <handlers.h>
#include <string>
#include <stdio.h>


class IOManager
{
public:
    enum Mode { Record, Verify };

    IOManager( const std::string& vignette, Mode mode );
    ~IOManager();

    bool isOk() const { return m_isOk; }
    bool atEOF() const;

    void process( const std::string& string );

private:
    std::string getNextLine();
    bool fillBuffer();
    void readFromBuffer( std::string& s );

    static const int BUFLEN = 1024;
    Mode m_mode;
    FILE* m_vignette;
    char* m_buffer;
    size_t m_bufindex;
    size_t m_buflen;
    bool m_isOk; // crap, no exception support
};


class InlineReplacementTest : public wvWare::InlineReplacementHandler
{
public:
    InlineReplacementTest( IOManager* iomanager );

    virtual wvWare::U8 tab();
    virtual wvWare::U8 hardLineBreak();
    virtual wvWare::U8 nonBreakingHyphen();
    virtual wvWare::U8 nonRequiredHyphen();
    virtual wvWare::U8 nonBreakingSpace();

private:
    IOManager* m_iomanager;
};


class TextTest : public wvWare::TextHandler
{
public:
    TextTest( IOManager* iomanager );

    virtual void sectionStart( wvWare::SharedPtr<const wvWare::Word97::SEP> sep );
    virtual void sectionEnd();
    virtual void pageBreak();

    virtual void headersFound( const wvWare::HeaderFunctor& parseHeaders );

    virtual void paragraphStart( wvWare::SharedPtr<const wvWare::ParagraphProperties> paragraphProperties );
    virtual void paragraphEnd();

    virtual void runOfText( const wvWare::UString& text, wvWare::SharedPtr<const wvWare::Word97::CHP> chp );

    virtual void specialCharacter( SpecialCharacter character, wvWare::SharedPtr<const wvWare::Word97::CHP> chp );

    virtual void footnoteFound( wvWare::FootnoteData::Type type, wvWare::UChar character,
                                wvWare::SharedPtr<const wvWare::Word97::CHP> chp, const wvWare::FootnoteFunctor& parseFootnote );
    virtual void footnoteAutoNumber( wvWare::SharedPtr<const wvWare::Word97::CHP> chp );

    virtual void fieldStart( const wvWare::FLD* fld, wvWare::SharedPtr<const wvWare::Word97::CHP> chp );
    virtual void fieldSeparator( const wvWare::FLD* fld, wvWare::SharedPtr<const wvWare::Word97::CHP> chp );
    virtual void fieldEnd( const wvWare::FLD* fld, wvWare::SharedPtr<const wvWare::Word97::CHP> chp );

private:
    IOManager* m_iomanager;
};

#endif // HANDLERTEST_H
